aboutsummaryrefslogtreecommitdiff
path: root/libbutl
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2020-06-19 14:50:04 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2020-06-19 14:50:04 +0200
commit0945b005c736e956eafa4c4688601fd15fed4e36 (patch)
treeead2ea2d9c2a74906347440621ffaf56e74c78e8 /libbutl
parent09d374dce1177cd5dcc1d64d5eb8f5e0b2337da6 (diff)
Fix terminology
Diffstat (limited to 'libbutl')
-rw-r--r--libbutl/builtin.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/libbutl/builtin.cxx b/libbutl/builtin.cxx
index 940e5a0..c6083b6 100644
--- a/libbutl/builtin.cxx
+++ b/libbutl/builtin.cxx
@@ -1287,7 +1287,7 @@ namespace butl
// rename() function) this is a noop.
//
if (exists && to == from)
- fail () << "unable to move entity '" << from << "' to itself";
+ fail () << "unable to move entry '" << from << "' to itself";
// Rename/move the filesystem entry, replacing an existing one.
//
@@ -1300,7 +1300,7 @@ namespace butl
}
catch (const system_error& e)
{
- fail () << "unable to move entity '" << from << "' to '" << to
+ fail () << "unable to move entry '" << from << "' to '" << to
<< "': " << e;
}
};
@@ -1321,7 +1321,7 @@ namespace butl
fail () << "multiple source paths without trailing separator for "
<< "destination directory";
// Synopsis 1: move an entity to the specified path.
//
mv (src, dst);
}
@@ -1321,7 +1321,7 @@ namespace butl
fail () << "multiple source paths without trailing separator for "
<< "destination directory";
- // Synopsis 1: move an entity to the specified path.
+ // Synopsis 1: move an entry to the specified path.
//
mv (src, dst);